==> jc-1.4.0.tar.gz: gnu/regexp/RETokenRepeated.h <==
// final class gnu.regexp.RETokenRepeated

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class e3ae5fcc5d49cf29 gnu_regexp_RETokenRepeated
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenRepeated_H_
#define _JC_gnu_regexp_RETokenRepeated_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_gnu_regexp_REToken$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenRepeated$sub_refs	_jc_gnu_regexp_RETokenRepeated$sub_refs;
typedef struct _jc_gnu_regexp_RETokenRepeated$sub_nonrefs	_jc_gnu_regexp_RETokenRepeated$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenRepeated$refs	_jc_gnu_regexp_RETokenRepeated$refs;
typedef struct _jc_gnu_regexp_RETokenRepeated$nonrefs	_jc_gnu_regexp_RETokenRepeated$nonrefs;
typedef struct _jc_gnu_regexp_RETokenRepeated$object	_jc_gnu_regexp_RETokenRepeated$object;

typedef const struct _jc_gnu_regexp_RETokenRepeated$vmethods	_jc_gnu_regexp_RETokenRepeated$vmethods;
typedef const struct _jc_gnu_regexp_RETokenRepeated$vtable	_jc_gnu_regexp_RETokenRepeated$vtable;
typedef const struct _jc_gnu_regexp_RETokenRepeated$vtype	_jc_gnu_regexp_RETokenRepeated$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenRepeated$method$_init$34660b4951536a12(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, jint, struct _jc_gnu_regexp_REToken$object *, jint, jint);

// Virtual methods
extern void _jc_gnu_regexp_RETokenRepeated$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_java_lang_StringBuffer$object *);
extern jint _jc_gnu_regexp_RETokenRepeated$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *);
extern jboolean _jc_gnu_regexp_RETokenRepeated$method$isStingy$915d76ba4d669db5(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *);
extern void _jc_gnu_regexp_RETokenRepeated$method$makeStingy$0decce43dcc83650(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *);
extern jboolean _jc_gnu_regexp_RETokenRepeated$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
extern struct _jc_gnu_regexp_REMatch$object *_jc_gnu_regexp_RETokenRepeated$method$matchRest$2396f43a5d61864c(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$isStingy$915d76ba4d669db5;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$makeStingy$0decce43dcc83650;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$match$d139de67a06a4f32;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$matchRest$2396f43a5d61864c;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenRepeated$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_java_lang_StringBuffer$object *);
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *);
	jboolean	(*isStingy$915d76ba4d669db5)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *);
	void	(*makeStingy$0decce43dcc83650)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
	struct _jc_gnu_regexp_REMatch$object	*(*matchRest$2396f43a5d61864c)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenRepeated$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenRepeated$vmethods	gnu_regexp_RETokenRepeated;
};

// Vtype
struct _jc_gnu_regexp_RETokenRepeated$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenRepeated$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRepeated$sub_refs {
	struct _jc_gnu_regexp_REToken$object	*token;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenRepeated$refs {
    _jc_gnu_regexp_RETokenRepeated$sub_refs	gnu_regexp_RETokenRepeated;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRepeated$sub_nonrefs {
	jint	min;
	jint	max;
	jboolean	stingy;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenRepeated$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenRepeated$sub_nonrefs	gnu_regexp_RETokenRepeated;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenRepeated$object {
	_jc_gnu_regexp_RETokenRepeated$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenRepeated$vtype	*vtype;
	_jc_gnu_regexp_RETokenRepeated$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenRepeated$vtype _jc_gnu_regexp_RETokenRepeated$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenRepeated, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenRepeated$class_object;

#endif	/* _JC_gnu_regexp_RETokenRepeated_H_ */

==> jc-1.4.5.tar.gz: gnu/regexp/RETokenRepeated.h <==
// final class gnu.regexp.RETokenRepeated

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class e3ae5fcc5d49cf29 gnu_regexp_RETokenRepeated
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenRepeated_H_
#define _JC_gnu_regexp_RETokenRepeated_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_gnu_regexp_REToken$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenRepeated$sub_refs	_jc_gnu_regexp_RETokenRepeated$sub_refs;
typedef struct _jc_gnu_regexp_RETokenRepeated$sub_nonrefs	_jc_gnu_regexp_RETokenRepeated$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenRepeated$refs	_jc_gnu_regexp_RETokenRepeated$refs;
typedef struct _jc_gnu_regexp_RETokenRepeated$nonrefs	_jc_gnu_regexp_RETokenRepeated$nonrefs;
typedef struct _jc_gnu_regexp_RETokenRepeated$object	_jc_gnu_regexp_RETokenRepeated$object;

typedef const struct _jc_gnu_regexp_RETokenRepeated$vmethods	_jc_gnu_regexp_RETokenRepeated$vmethods;
typedef const struct _jc_gnu_regexp_RETokenRepeated$vtable	_jc_gnu_regexp_RETokenRepeated$vtable;
typedef const struct _jc_gnu_regexp_RETokenRepeated$vtype	_jc_gnu_regexp_RETokenRepeated$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenRepeated$method$_init$34660b4951536a12(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, jint, struct _jc_gnu_regexp_REToken$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenRepeated$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_RETokenRepeated$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenRepeated$method$isStingy$915d76ba4d669db5(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_RETokenRepeated$method$makeStingy$0decce43dcc83650(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenRepeated$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_regexp_REMatch$object *_jc_gnu_regexp_RETokenRepeated$method$matchRest$2396f43a5d61864c(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$isStingy$915d76ba4d669db5;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$makeStingy$0decce43dcc83650;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$match$d139de67a06a4f32;
extern _jc_method _jc_gnu_regexp_RETokenRepeated$method_info$matchRest$2396f43a5d61864c;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenRepeated$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *) _JC_JCNI_ATTR;
	jboolean	(*isStingy$915d76ba4d669db5)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *) _JC_JCNI_ATTR;
	void	(*makeStingy$0decce43dcc83650)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_regexp_REMatch$object	*(*matchRest$2396f43a5d61864c)(_jc_env *, struct _jc_gnu_regexp_RETokenRepeated$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenRepeated$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenRepeated$vmethods	gnu_regexp_RETokenRepeated;
};

// Vtype
struct _jc_gnu_regexp_RETokenRepeated$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenRepeated$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRepeated$sub_refs {
	struct _jc_gnu_regexp_REToken$object	*token;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenRepeated$refs {
    _jc_gnu_regexp_RETokenRepeated$sub_refs	gnu_regexp_RETokenRepeated;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRepeated$sub_nonrefs {
	jint	min;
	jint	max;
	jboolean	stingy;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenRepeated$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenRepeated$sub_nonrefs	gnu_regexp_RETokenRepeated;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenRepeated$object {
	_jc_gnu_regexp_RETokenRepeated$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenRepeated$vtype	*vtype;
	_jc_gnu_regexp_RETokenRepeated$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenRepeated$vtype _jc_gnu_regexp_RETokenRepeated$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenRepeated, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenRepeated$class_object;

#endif	/* _JC_gnu_regexp_RETokenRepeated_H_ */
